# eric7.Project.RccCompilerOptionsDialog

Module implementing a dialog to enter some non-common rcc compiler options.

### Global Attributes

None

### Classes

RccCompilerOptionsDialog | Class implementing a dialog to enter some non-common rcc compiler options.

### Functions

None

## RccCompilerOptionsDialog

Class implementing a dialog to enter some non-common rcc compiler options.

### Derived from

QDialog, Ui_RccCompilerOptionsDialog

### Class Attributes

None

### Class Methods

None

### Methods

RccCompilerOptionsDialog | Constructor
getData | Public method to get the entered data.

### Static Methods

None

#### RccCompilerOptionsDialog (Constructor)

RccCompilerOptionsDialog(compilerOptions, parent=None)

Constructor

compilerOptions (dict)
  dictionary containing the rcc compiler options
parent (QWidget)
  reference to the parent widget

#### RccCompilerOptionsDialog.getData

getData()

Public method to get the entered data.

Return:
  tuple containing the compression threshold, compression level, flag indicating to disable compression and the resource access path prefix

Return Type:
  tuple of (int, int, bool, str)

Up